package uk.ac.cf.spring.demo.util;

import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import uk.ac.cf.spring.demo.user.User;
import uk.ac.cf.spring.demo.user.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import java.util.Optional;

public class SecurityUtils {

    @Autowired
    private UserRepository userRepository;

    // 获取当前认证对象
    public static Authentication getAuthentication() {
        return SecurityContextHolder.getContext().getAuthentication();
    }

    // 检查当前用户是否为管理员
    public static boolean isAdmin() {
        Authentication authentication = getAuthentication();
        return authentication.getAuthorities().stream()
                .anyMatch(authority -> authority.getAuthority().equals("ROLE_ADMIN"));
    }

    // 获取当前用户的角色
    public static String getCurrentUserRole() {
        Authentication authentication = getAuthentication();
        return authentication.getAuthorities().stream()
                .map(authority -> authority.getAuthority())
                .findFirst()
                .orElse("ROLE_USER");
    }

    // 获取当前用户名
    public static String getCurrentUsername() {
        Authentication authentication = getAuthentication();
        return authentication.getName();
    }

    // 从数据库中加载当前用户详细信息
    public Optional<User> getCurrentUserDetails() {
        String username = getCurrentUsername();
        return userRepository.findByUsername(username);
    }
}
