let currentIndex = 0;
let images = []; // This will hold the URLs of the images

// Load images into the carousel
function loadImages() {
    const carouselImages = document.getElementById("carousel-images");
    carouselImages.innerHTML = ""; // Clear current images

    images.forEach((imageUrl, index) => {
        const img = document.createElement("img");
        img.src = imageUrl; // Correctly use the URL for the image src
        console.log(img.src)
        img.alt = `Image ${index + 1}`;
        img.style.display = index === currentIndex ? "block" : "none";
        carouselImages.appendChild(img);
    });
}

// Show previous image
function prevImage() {
    currentIndex = (currentIndex - 1 + images.length) % images.length;
    loadImages();
}

// Show next image
function nextImage() {
    currentIndex = (currentIndex + 1) % images.length;
    loadImages();
}

// Upload image
function uploadImage(event) {
    const file = event.target.files[0];
    if (!file) return;

    const formData = new FormData();
    formData.append("image", file);

    fetch("/api/images", {
        method: "POST",
        body: formData,
    })
        .then(response => {
            if (!response.ok) {
                throw new Error("Failed to upload image");
            }
            return response.json();
        })
        .then(data => {
            images.push(data.url); // Assuming the server returns the image URL
            loadImages();
        })
        .catch(error => {
            console.error("Error uploading image:", error);
        });
}

// Initialize the gallery on page load
window.onload = () => {
    fetch("/api/images")
        .then(response => response.json())
        .then(data => {
            images = data.map(image => image.url); // Extract URLs from the server response
            loadImages();
        })
        .catch(error => {
            console.error("Error loading images:", error);
        });
};

