// 数据库
const data = [
    {
        title: 'Pools Rules',
        description: 'Learn the basic rules of pools, including scoring and penalties.',
        url: 'https://rileys.co.uk/games/english-pool'
    },
    {
        title: 'Darts Rules',
        description: 'An overview of darts rules, including fouls and court dimensions.',
        url: 'http://localhost:8080/html/dartsrules.html'
    },
    {
        title: 'Table-Tennis Rules',
        description: 'Understand the rules of table-tennis, including scoring and serving.',
        url: 'http://localhost:8080/html/table-tennisrules.html'
    },

];

// 初始化 Fuse.js
const fuse = new Fuse(data, {
    includeScore: true,
    keys: ['title', 'description']
});

// 元素获取
const searchBar = document.getElementById('search-bar');
const searchResults = document.getElementById('search-results');

// 页面加载时显示所有规则
renderResults(data);

// 搜索监听
searchBar.addEventListener('input', (event) => {
    const query = event.target.value.trim();
    if (query === '') {
        renderResults(data); // 显示全部
        return;
    }

    // 执行搜索
    const results = fuse.search(query).map(result => result.item);
    renderResults(results);
});

// 渲染结果
function renderResults(results) {
    searchResults.innerHTML = '';

    if (results.length === 0) {
        searchResults.innerHTML = '<p>No results found.</p>';
        return;
    }

    results.forEach(item => {
        const { title, description, url } = item;

        // 创建结果项
        const itemDiv = document.createElement('div');
        itemDiv.className = 'search-result-item';

        const link = document.createElement('a');
        link.href = url;
        link.target = '_blank';

        const titleElement = document.createElement('h3');
        titleElement.textContent = title;

        const descriptionElement = document.createElement('p');
        descriptionElement.textContent = description;

        link.appendChild(titleElement);
        itemDiv.appendChild(link);
        itemDiv.appendChild(descriptionElement);
        searchResults.appendChild(itemDiv);
    });
}

