package uk.ac.cf.spring.demo;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.http.ResponseEntity;

import java.util.HashMap;
import java.util.Map;

import static org.assertj.core.api.Assertions.assertThat;

@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
public class HTTPConnectionTest {

    // 通过 Spring 注入的端口
    @Value(value = "${local.server.port}")
    private int port;

    // RestTemplate 用于发送 HTTP 请求
    @Autowired
    private TestRestTemplate restTemplate;

    // 提取常量，避免在每个测试方法中重复
    private String baseUrl() {
        return "http://localhost:" + port;
    }

    // 测试页面加载是否包含指定内容
    @Test
    public void greetingShouldReturnDefaultMessage() throws Exception {
        String url = baseUrl() + "/html/matchSchedule.html";

        // 使用 RestTemplate 发送 GET 请求并检查返回内容
        String response = this.restTemplate.getForObject(url, String.class);

        // 检查响应中是否包含 "Sport" 字样
        assertThat(response).contains("Sport");
    }

    // 测试数据库接口（模拟用户登录并检查后续请求）
    @Test
    public void dbMatchTest() throws Exception {
        String loginUrl = baseUrl() + "/api/users/login";
        String matchUrl = baseUrl() + "/match";

        // 准备登录数据
        Map<String, String> loginData = new HashMap<>();
        loginData.put("email", "shy@creditsafe.com");
        loginData.put("password", "shy");

        // 发送 POST 请求模拟登录
        ResponseEntity<String> loginResponse = this.restTemplate.postForEntity(loginUrl, loginData, String.class);

        // 验证登录成功消息
        assertThat(loginResponse.getBody()).contains("Login successful");

        // 检查 match 接口返回的内容是否包含 "Pools" 字段
        String matchResponse = this.restTemplate.getForObject(matchUrl, String.class);
        assertThat(matchResponse).contains("Pools");
    }
}
