package uk.ac.cf.spring.demo;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.http.MediaType;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders;
import org.springframework.test.web.servlet.result.MockMvcResultMatchers;
import uk.ac.cf.spring.demo.sports.match.MatchItem;
import uk.ac.cf.spring.demo.sports.match.MatchService;


import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

import static org.mockito.Mockito.when;
//Lightweight Mock MVC
// Integration

@SpringBootTest
@AutoConfigureMockMvc
public class LightweightMockMVCIntegrationTests {

    @Autowired
    private MockMvc mockMvc;
    @MockBean
    private MatchService matchService;

    @WithMockUser(username = "shy", password = "shy") // 模拟已认证用户
    @Test
    public void testGetAllMatchItems() throws Exception {
        MatchItem matchItem1 = new MatchItem(1L, "Pools", 1L, 2L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);
        MatchItem matchItem2 = new MatchItem(2L, "Darts", 3L, 4L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);
        List<MatchItem> matchItems = Arrays.asList(matchItem1, matchItem2);

        when(matchService.getMatchItems()).thenReturn(matchItems);


        mockMvc.perform(MockMvcRequestBuilders.get("/match")
                        .contentType(MediaType.APPLICATION_JSON)) // 设置请求类型
                .andExpect(MockMvcResultMatchers.status().isOk()) // 期望返回 200
                .andExpect(MockMvcResultMatchers.jsonPath("$[0].id").value(1))
                .andExpect(MockMvcResultMatchers.jsonPath("$[0].sport").value("Pools"))
                .andExpect(MockMvcResultMatchers.jsonPath("$[1].id").value(2))
                .andExpect(MockMvcResultMatchers.jsonPath("$[1].sport").value("Darts"));
    }
    @WithMockUser(username = "shy", password = "shy")
    @Test
    public void testGetMatchItemById() throws Exception {
        // Prepare a specific match item
        MatchItem matchItem = new MatchItem(1L, "Pools", 1L, 2L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);

        // Mocking the service method
        when(matchService.getMatchItemById(1L)).thenReturn(matchItem);

        // Perform the GET request and verify the result
        mockMvc.perform(MockMvcRequestBuilders.get("/match/1"))
                .andExpect(MockMvcResultMatchers.status().isOk())
                .andExpect(MockMvcResultMatchers.jsonPath("$.id").value(1))
                .andExpect(MockMvcResultMatchers.jsonPath("$.sport").value("Pools"));
    }
    @WithMockUser(username = "shy", password = "shy")
    @Test
    public void testAddMatchItem() throws Exception {
        // Prepare the match item to be added
        MatchItem matchItem = new MatchItem(null, "Tennis", 1L, 2L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);

        // Perform the POST request
        mockMvc.perform(MockMvcRequestBuilders.post("/match")
                        .contentType(MediaType.APPLICATION_JSON)
                        .content("{\"sport\":\"Tennis\",\"team1\":1,\"team2\":2,\"date\":\"" + LocalDateTime.now() + "\",\"status\":\"pending\",\"score1\":0,\"score2\":0,\"isLive\":false,\"isFinished\":false,\"duration\":0}"))
                .andExpect(MockMvcResultMatchers.status().isOk());
    }
    @WithMockUser(username = "shy", password = "shy")
    @Test
    public void testUpdateMatchItem() throws Exception {
        // Prepare the match item to be updated
        MatchItem matchItem = new MatchItem(1L, "Pools", 1L, 2L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);

        // Mocking the service method
        when(matchService.getMatchItemById(1L)).thenReturn(matchItem);

        // Perform the PUT request
        mockMvc.perform(MockMvcRequestBuilders.put("/match/1")
                        .contentType(MediaType.APPLICATION_JSON)
                        .content("{\"id\":1,\"sport\":\"Pools\",\"team1\":1,\"team2\":2,\"date\":\"" + LocalDateTime.now() + "\",\"status\":\"pending\",\"score1\":0,\"score2\":0,\"isLive\":false,\"isFinished\":false,\"duration\":0}"))
                .andExpect(MockMvcResultMatchers.status().isOk());
    }
    @WithMockUser(username = "shy", password = "shy")
    @Test
    public void testDeleteMatchItem() throws Exception {
        // Perform the DELETE request
        mockMvc.perform(MockMvcRequestBuilders.delete("/match/1"))
                .andExpect(MockMvcResultMatchers.status().isOk());
    }
}

