package uk.ac.cf.spring.demo;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;
import uk.ac.cf.spring.demo.sports.match.MatchController;
import uk.ac.cf.spring.demo.sports.match.MatchItem;
import uk.ac.cf.spring.demo.sports.match.MatchService;

import java.util.Arrays;
import java.util.List;

import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

@SpringBootTest
public class MatchControllerTest {

    @Mock
    private MatchService matchService;

    @InjectMocks
    private MatchController matchController;

    private MockMvc mockMvc;

    @BeforeEach
    void setUp() {
        mockMvc = MockMvcBuilders.standaloneSetup(matchController).build();
    }

    @Test
    void testGetAllMatches() throws Exception {
        MatchItem match1 = new MatchItem(1L, "Soccer", 1L, 2L, null, "completed", 2L, 3L, true, true, 2L);
        List<MatchItem> matches = Arrays.asList(match1);

        when(matchService.getMatchItems()).thenReturn(matches);

        mockMvc.perform(get("/match"))
                .andExpect(status().isOk());

        verify(matchService, times(1)).getMatchItems();
    }

    @Test
    void testGetMatchById() throws Exception {
        MatchItem match1 = new MatchItem(1L, "Soccer", 1L, 2L, null, "completed", 2L, 3L, true, true, 2L);

        when(matchService.getMatchItemById(1L)).thenReturn(match1);

        mockMvc.perform(get("/match/1"))
                .andExpect(status().isOk());

        verify(matchService, times(1)).getMatchItemById(1L);
    }
}
