package uk.ac.cf.spring.demo;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;
import uk.ac.cf.spring.demo.sports.match.MatchItem;
import uk.ac.cf.spring.demo.sports.match.MatchRepository;
import uk.ac.cf.spring.demo.sports.match.MatchServiceListImpl;

import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

import static org.mockito.Mockito.*;
import static org.junit.jupiter.api.Assertions.*;

@ExtendWith(MockitoExtension.class) // 使得 Mockito 能够工作
public class MatchServiceTest {

    @Mock
    private MatchRepository matchRepository; // 模拟 MatchRepository

    @InjectMocks
    private MatchServiceListImpl matchService; // 注入 MatchServiceListImpl

    private MatchItem matchItem1;
    private MatchItem matchItem2;

    @BeforeEach
    public void setUp() {
        // 设置一些初始的 MatchItem 数据
        matchItem1 = new MatchItem(1L, "Soccer", 1L, 2L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);
        matchItem2 = new MatchItem(2L, "Basketball", 3L, 4L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);
    }

    @Test
    public void testGetMatchItems() {

        when(matchRepository.getMatchItems()).thenReturn(Arrays.asList(matchItem1, matchItem2));
        List<MatchItem> matchItems = matchService.getMatchItems();
        assertNotNull(matchItems);
        assertEquals(2, matchItems.size());
        assertEquals("Soccer", matchItems.get(0).getSport());
        assertEquals("Basketball", matchItems.get(1).getSport());
        verify(matchRepository, times(1)).getMatchItems();
    }

    @Test
    public void testGetMatchItemById() {

        when(matchRepository.getMatchItemById(1L)).thenReturn(matchItem1);
        MatchItem matchItem = matchService.getMatchItemById(1L);
        assertNotNull(matchItem);
        assertEquals(1L, matchItem.getId());
        assertEquals("Soccer", matchItem.getSport());

        verify(matchRepository, times(1)).getMatchItemById(1L);
    }

    @Test
    public void testAddMatchItem() {
        MatchItem newMatchItem = new MatchItem(0L, "Tennis", 5L, 6L, LocalDateTime.now(), "pending", 0L, 0L, false, false, 0L);
        matchService.addMatchItem(newMatchItem);
        verify(matchRepository, times(1)).addMatchItem(newMatchItem);
    }
}
